import { OnChanges } from '@angular/core';
import { Channel, User } from 'stream-chat';
import { CustomTemplatesService } from '../custom-templates.service';
import { AvatarContext, AvatarLocation, AvatarType } from '../types';
import * as i0 from "@angular/core";
/**
 * The `AvatarPlaceholder` component displays the [default avatar](/chat/docs/sdk/angular/components/AvatarComponent/) unless a [custom template](/chat/docs/sdk/angular/services/CustomTemplatesService/) is provided. This component is used by the SDK internally, you likely won't need to use it.
 */
export declare class AvatarPlaceholderComponent implements OnChanges {
    customTemplatesService: CustomTemplatesService;
    /**
     * An optional name of the image, used for fallback image or image title (if `imageUrl` is provided)
     */
    name: string | undefined;
    /**
     * The URL of the image to be displayed. If the image can't be displayed the first letter of the name input is displayed.
     */
    imageUrl: string | undefined;
    /**
     * The location the avatar will be displayed in
     */
    location: AvatarLocation | undefined;
    /**
     * The channel the avatar belongs to (if avatar of a channel is displayed)
     */
    channel?: Channel;
    /**
     * The user the avatar belongs to (if avatar of a user is displayed)
     */
    user?: User;
    /**
     * The type of the avatar: channel if channel avatar is displayed, user if user avatar is displayed
     */
    type: AvatarType | undefined;
    /**
     * If channel/user image isn't provided the initials of the name of the channel/user is shown instead, you can choose how the initals should be computed
     */
    initialsType: 'first-letter-of-first-word' | 'first-letter-of-each-word';
    /**
     * If a channel avatar is displayed, and if the channel has exactly two members a green dot is displayed if the other member is online. Set this flag to `false` to turn off this behavior.
     */
    showOnlineIndicator: boolean;
    context: AvatarContext;
    constructor(customTemplatesService: CustomTemplatesService);
    ngOnChanges(): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<AvatarPlaceholderComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<AvatarPlaceholderComponent, "stream-avatar-placeholder", never, { "name": "name"; "imageUrl": "imageUrl"; "location": "location"; "channel": "channel"; "user": "user"; "type": "type"; "initialsType": "initialsType"; "showOnlineIndicator": "showOnlineIndicator"; }, {}, never, never, false, never>;
}
