import { AfterViewInit, ChangeDetectorRef, NgZone, OnChanges, OnDestroy, OnInit, SimpleChanges } from '@angular/core';
import { Channel, User } from 'stream-chat';
import { ChatClientService } from '../chat-client.service';
import { AvatarLocation, AvatarType } from '../types';
import * as i0 from "@angular/core";
/**
 * The `Avatar` component displays the provided image, with fallback to the first letter of the optional name input.
 */
export declare class AvatarComponent implements OnChanges, OnInit, OnChanges, AfterViewInit, OnDestroy {
    private chatClientService;
    private ngZone;
    private cdRef;
    /**
     * An optional name of the image, used for fallback image or image title (if `imageUrl` is provided)
     */
    name: string | undefined;
    /**
     * The URL of the image to be displayed. If the image can't be displayed the first letter of the name input is displayed.
     */
    imageUrl: string | undefined;
    /**
     * The location the avatar will be displayed in
     */
    location: AvatarLocation | undefined;
    /**
     * The channel the avatar belongs to (if avatar of a channel is displayed)
     */
    channel?: Channel;
    /**
     * The user the avatar belongs to (if avatar of a user is displayed)
     */
    user?: User;
    /**
     * The type of the avatar: channel if channel avatar is displayed, user if user avatar is displayed
     */
    type: AvatarType | undefined;
    /**
     * If a channel avatar is displayed, and if the channel has exactly two members a green dot is displayed if the other member is online. Set this flag to `false` to turn off this behavior.
     */
    showOnlineIndicator: boolean;
    /**
     * If channel/user image isn't provided the initials of the name of the channel/user is shown instead, you can choose how the initals should be computed
     */
    initialsType: 'first-letter-of-first-word' | 'first-letter-of-each-word';
    isError: boolean;
    isOnline: boolean;
    private isOnlineSubscription?;
    initials: string;
    fallbackChannelImage: string | undefined;
    private userId?;
    private isViewInited;
    private subscriptions;
    constructor(chatClientService: ChatClientService, ngZone: NgZone, cdRef: ChangeDetectorRef);
    ngOnInit(): void;
    ngOnChanges(changes: SimpleChanges): void;
    ngOnDestroy(): void;
    private setFallbackChannelImage;
    private setInitials;
    private updateIsOnlineSubscription;
    ngAfterViewInit(): void;
    private getOtherMemberIfOneToOneChannel;
    static ɵfac: i0.ɵɵFactoryDeclaration<AvatarComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<AvatarComponent, "stream-avatar", never, { "name": "name"; "imageUrl": "imageUrl"; "location": "location"; "channel": "channel"; "user": "user"; "type": "type"; "showOnlineIndicator": "showOnlineIndicator"; "initialsType": "initialsType"; }, {}, never, never, false, never>;
}
